NAME

WWW::Picnic::Result - Base class for Picnic API result objects

VERSION

version 0.101

SYNOPSIS

# Base class for all result objects, not used directly
package WWW::Picnic::Result::Something;
use Moo;
extends 'WWW::Picnic::Result';

DESCRIPTION

This is the base class for all WWW::Picnic result objects. It provides common functionality for deserializing API responses into Perl objects.

raw

The raw hashref data from the API response. Useful for accessing fields that don't have dedicated accessors yet.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-www-picnic/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <torsten@raudssus.de>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudss.us/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.